EnglishNumberFlagsControl class final

A hash-delimited number-normalization flag control.

Inheritance

Properties

encoded String
Exact normalized upstream feature, including its leading hash.
final
flags String
Flags assigned by the downstream tokenizer.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited