encoded property
Exact normalized upstream feature, including its leading hash.
All trailing hashes are removed except for the single discriminator.
Implementation
final String encoded;
Exact normalized upstream feature, including its leading hash.
All trailing hashes are removed except for the single discriminator.
final String encoded;