text property
Input with leading Python whitespace removed and valid link syntax replaced by each link's visible source text.
Implementation
final String text;
Input with leading Python whitespace removed and valid link syntax replaced by each link's visible source text.
final String text;