EnglishPronunciationControl class final

A slash-delimited custom pronunciation control.

Inheritance

Properties

encoded String
Exact normalized upstream feature, including its leading slash.
final
hashCode int
The hash code for this object.
no setterinherited
phonemes String
Pronunciation assigned by the downstream tokenizer.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited