EnglishStressControl class final

A signed integral or half-step stress control.

Inheritance

Constructors

EnglishStressControl(num stress)
Creates a stress control with stress.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stress num
Upstream stress value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited