HebrewOptions class final

Options forwarded unchanged to a Hebrew phonemizer backend.

These are the two keyword options exposed by pinned misaki/he.py:

const options = HebrewOptions(
  preservePunctuation: false,
  preserveStress: true,
);

Constructors

HebrewOptions({bool preservePunctuation = true, bool preserveStress = true})
Creates Hebrew conversion options.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
preservePunctuation bool
Whether punctuation is retained in the phoneme output.
final
preserveStress bool
Whether stress marks are retained in the phoneme output.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited