VietnameseDialect enum

Vietnamese pronunciation dialect.

Inheritance
Available extensions

Values

north → const VietnameseDialect

Northern pronunciation (n).

const VietnameseDialect('n')
central → const VietnameseDialect

Central pronunciation (c).

const VietnameseDialect('c')
south → const VietnameseDialect

Southern pronunciation (s).

const VietnameseDialect('s')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upstreamCode String
One-letter code consumed by the pinned phonology rules.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VietnameseDialect>
A constant List of the values in this enum, in order of their declaration.