VietnameseToneType enum

Upstream tone_type selection.

Inheritance
Available extensions

Values

pham → const VietnameseToneType

tone_type == 0, which forces the Phạm digit system on.

cao → const VietnameseToneType

Any nonzero tone_type, which forces the Cao digit system on.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VietnameseToneType>
A constant List of the values in this enum, in order of their declaration.