EnglishInlinePreprocessor class final
Pure parser for Misaki's English inline controls.
Constructors
- EnglishInlinePreprocessor()
-
Creates a stateless English inline preprocessor.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preprocess(
String input) → EnglishPreprocessResult -
Removes inline syntax from
inputand records each valid control. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited