EnglishPreprocessResult class final
Immutable output of EnglishInlinePreprocessor.preprocess.
Constructors
-
EnglishPreprocessResult({required String text, required List<
String> sourceWords, required Map<int, EnglishInlineControl> controls}) - Creates a result and defensively freezes its collections.
Properties
-
controls
→ Map<
int, EnglishInlineControl> -
Inline controls keyed by index in sourceWords.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceWords
→ List<
String> -
Source strings used later to align controls with backend tokens.
final
- text → String
-
Input with leading Python whitespace removed and valid link syntax
replaced by each link's visible source text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited