EnglishTokenContext class final

Right-to-left context used by the pinned English lexicon.

Constructors

EnglishTokenContext({bool? futureVowel, bool futureTo = false})
Creates English token context.
const

Properties

futureTo bool
Whether the token immediately to the right is the context-sensitive to.
final
futureVowel bool?
Whether the next significant phoneme is a vowel, a consonant, or unknown.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited