JapaneseNumberConverter class final
Converts Arabic-number text to Japanese and Japanese kanji to Arabic text.
The converter is pure Dart and has no backend or runtime-data dependency. It preserves the pinned upstream converter's nine-character limit after commas are removed.
Constructors
- JapaneseNumberConverter()
-
Creates a stateless Japanese number converter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(
String number, {JapaneseNumberFormat format = JapaneseNumberFormat.hiragana}) → String -
Converts ASCII
numbertext into the selected Japaneseformat. -
kanjiToArabic(
String number) → String -
Converts Japanese
numbertext into an Arabic-number string. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited