Explicit tokenizer boundary matching underthesea's tokenize function.
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → BackendInfo
-
Stable backend identity included in diagnostics and fixture metadata.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tokenize(
String text) → List< String> -
Returns exact ordered token strings for cleaned
text. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited